.. pysiss.borehole documentation master file, created by
   sphinx-quickstart on Fri Oct 19 11:34:51 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _intro:

welcome to PySISS!
******************

We want to make it easy to perform geological data analysis based on SISS services (including boreholes & geological measurements, raster and vector map data, and vocabularies) within Python using your favourite Python libraries. 

This library is released under the CSIRO BSD/MIT license, whose terms are available in the `LICENSE.md` file. 

**Warning** - this library is in a pre-alpha state and could change without warning.

Probably the easiest way to get a feel for the behavior of the library is to have a look at the use cases supplied in pysiss-cookbook, available on Github at http://github.com/pysiss/pysiss-cookbook.

Getting started
---------------

.. toctree::
   :maxdepth: 2

   building
   examples

API reference
-------------

.. toctree::
   :maxdepth: 2

   borehole
   coverage
   metadata
   utilities
   vocabulary
   webservices


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

